@@ -1,5 +1,3 @@
-context("fit_members")
-
 if ((!on_cran()) || interactive()) {
   if (on_github()) {
     load(paste0(Sys.getenv("GITHUB_WORKSPACE"), "/tests/testthat/helper_data.Rda"))
@@ -8,6 +6,17 @@ if ((!on_cran()) || interactive()) {
   }
 }
 
+skip_if_not_installed("modeldata")
+library(modeldata)
+
+skip_if_not_installed("ranger")
+library(ranger)
+
+skip_if_not_installed("kernlab")
+library(kernlab)
+
+skip_if_not_installed("nnet")
+library(nnet)
 
 test_that("basic fit_members works", {
   skip_on_cran()
@@ -111,3 +120,36 @@ test_that("fit_members errors informatively with a bad model_stack arg", {
     "`model_stack` have already been fitted and need not"
   )
 })
+
+test_that("fit_members checks for required packages", {
+  skip_on_cran()
+  
+  skip_if_not_installed("mockr")
+  
+  library(mockr)
+  
+  # check pluralization of error
+  expect_snapshot_error(error_needs_install(letters[1], rep(FALSE, 1)))
+  expect_snapshot_error(error_needs_install(letters[1:2], rep(FALSE, 2)))
+  expect_snapshot_error(error_needs_install(letters[1:3], rep(FALSE, 3)))
+  
+  # loads dependency when it's installed but not loaded
+  unloadNamespace("kernlab")
+  
+  expect_s3_class(
+    st_reg_1_ %>%
+      fit_members(),
+    "model_stack"
+  )
+  
+  expect_true(isNamespaceLoaded("kernlab"))
+  
+  # errors informatively when it's not installed
+  mockr::with_mock(
+    is_installed_ = function(x) {FALSE},
+    {expect_snapshot_error(
+        st_reg_1_ %>%
+          fit_members()
+    )}
+  )
+})
